Learn R Programming

sampbias (version 2.0.0)

ea_raster: Equal Area Raster

Description

An example for an global equal area raster (in Behrmann projection) for the format needed for a custom grid provided to calculate_bias.

Usage

ea_raster

Arguments

Format

An object of class PackedSpatRaster of length 1.

Examples

Run this code

data(ea_raster)
ea_raster <- terra::unwrap(ea_raster)

Run the code above in your browser using DataLab