Learn R Programming

sampbias (version 2.0.0)

ecoregion_example: Detailed Example for a Custom Study Area

Description

An example of the format needed to provide custom areas for calculate_bias based on a publicly available set of global ecoregions.

Usage

ecoregion_example

Arguments

Format

An object of class sf (inherits from data.frame) with 7 rows and 22 columns.

Examples

Run this code

data(ecoregion_example)

Run the code above in your browser using DataLab