Learn R Programming

sampbias (version 2.0.0)

is.sampbias: Is Method for Class sampbias

Description

Check class of sampbias objects.

Usage

# S3 method for sampbias
is(object, class2 = "sampbias")

Value

The function returns a logical indicating whether the object is a is of the class sampbias.

Arguments

object

an object of the class sampbias

class2

the names of the class to which is relations are to be examined defined, or (more efficiently) the class definition objects for the classes.

Details

With two arguments, tests whether object can be treated as from class2. With one argument, returns all the super-classes of this object's class.

Examples

Run this code
# \donttest{
  #simulate data
  occ <- data.frame(species = rep(sample(x = LETTERS, size = 5), times = 10),
                   decimalLongitude = runif(n = 50, min = 12, max = 20),
                   decimalLatitude = runif(n = 50, min = -4, max = 4))

  out <- calculate_bias(x = occ, terrestrial = TRUE)
  is(out)
# }

Run the code above in your browser using DataLab