Learn R Programming

sampbias (version 2.0.0)

plot.sampbias: Plotting the Posterior Estimates of the Bias Weights

Description

Plotting method for class sampbias, generating a box-whiskers-plot showing the bias weights for all biasing factors indicating the effect strength for each gazetteer provided to calculate_bias.

Usage

# S3 method for sampbias
plot(x, ...)

Value

A plot

Arguments

x

an object of the class sampbias.

...

Additional arguments passed to summary.

See Also

calculate_bias, summary.sampbias

Examples

Run this code
# \donttest{
  #simulate data
  occ <- data.frame(species = rep(sample(x = LETTERS, size = 5), times = 10),
                   decimalLongitude = runif(n = 50, min = 12, max = 20),
                   decimalLatitude = runif(n = 50, min = -4, max = 4))

  out <- calculate_bias(x = occ, terrestrial = TRUE)
  summary(out)
  plot(out)
# }

Run the code above in your browser using DataLab