powered by
An example for an global equal area raster (in Behrmann projection) for the format needed for a custom grid provided to calculate_bias.
calculate_bias
ea_raster
An object of class PackedSpatRaster of length 1.
PackedSpatRaster
data(ea_raster) ea_raster <- terra::unwrap(ea_raster)
Run the code above in your browser using DataLab