powered by
An example of the format needed to provide custom areas for calculate_bias based on a publicly available set of global ecoregions.
calculate_bias
ecoregion_example
An object of class sf (inherits from data.frame) with 7 rows and 22 columns.
sf
data.frame
data(ecoregion_example)
Run the code above in your browser using DataLab